local gears={}
gears.effect = love.graphics.newPixelEffect[[

extern number time;
extern vec2 screen;

number pi = atan(1.)*4.;

struct Gear
	{
	vec2	pos;
	number	tn, ts, r, ang;
	};

void gearAngle( Gear p, inout Gear c )
	{
	number	ratio	= p.tn / c.tn;			//Gear ratio
	number	off		= pi / c.tn;			//One tooth offset
	c.ang 			= -p.ang * ratio + off;
	}

vec2 cnorm( vec2 v )
	{
	return v/max( abs(v.x), abs(v.y) );
	}

number inGear( Gear g, vec2 p )
	{
	p -= g.pos;
	number an = atan(p.x,p.y)+g.ang;
	number ra = length(p);

	vec2 cs	= vec2(cos(an*g.tn), sin(an*g.tn));
	cs		= cnorm(cs);

	return smoothstep(0.018, 0.02, distance(p, vec2(0., 0.)))*smoothstep(g.r+0.005,g.r,ra-(cs.x*.5+.5)*g.ts);
	}

vec4 effect( vec4 color, Image tex, vec2 tc, vec2 pc )
	{
	vec2	res	= vec2( screen.x / screen.y, 1 );
	vec2	p	= ( pc.xy / screen.y )-(res/2.);

	number 	a	= atan(p.x,p.y)+time;
	number	r	= length(p);

	vec3	c	= vec3(0.0);

	// gearAngle determines which gears rotate together
	// gear ratio must be an integers & equal to the diameter ratio
	// Gear			(location), 	# , length, diameter, rotation


	Gear g0 = Gear(vec2(-0.3,0),	16.,	0.03,	0.1,	time);

	Gear g1 = Gear(vec2(-0.3,0.24),	16.,	0.03,	0.1,	0.);
		gearAngle(g0,g1);

	Gear g2 = Gear(vec2(-0.252,-0.29),24.,	0.03,	0.15,	0.);
		gearAngle(g0,g2);

	Gear g3 = Gear(vec2(-0.06,0.),	16.,	0.03,	0.1,	0.);
		gearAngle(g0,g3);

	Gear g4 = Gear(vec2(0.13,0.),	8.,	0.03,	0.05,	0.);
		gearAngle(g3,g4);

	Gear g5 = Gear(vec2(0.221,0.23),24.,	0.03,	0.15,	0.);
		gearAngle(g4,g5);

	Gear g6 = Gear(vec2(-0.06,0.19),8.,	0.035,	0.04,	0.);
		gearAngle(g3,g6);

	Gear g7 = Gear(vec2(.391, -.01),	16.,	0.03,	0.10,	0.);
		gearAngle(g5,g7);

	Gear g8 = Gear(vec2(.295, -.265),	20.,0.03,	0.125,	0.);
		gearAngle(g7,g8);

	Gear g9 = Gear(vec2(.07, -.34),	10.,0.03,	0.0625,	0.);
		gearAngle(g8,g9);

	c  = inGear(g0,p)*vec3(.2,.2,.3);
	c += inGear(g1,p)*vec3(1.,1.,0.);
	c += inGear(g2,p)*vec3(1.,.1,.5);
	c += inGear(g3,p)*vec3(0.,0.,1.);
	c += inGear(g4,p)*vec3(.6,1.,.3);
	c += inGear(g5,p)*vec3(0.,1.,1.);
	c += inGear(g6,p)*vec3(.2,.2,.2);
	c += inGear(g7,p)*vec3(.2,.2,0);
	c += inGear(g8,p)*vec3(0,1,0);
	c += inGear(g9,p)*vec3(1,.5,0);
	return vec4( vec3( c ), 1.0 );
	}
]]
return gears
